@@ -127,6 +127,9 @@ fc_flags_append = {
     "gfortran-16": ["-fallow-invalid-boz", "-fallow-argument-mismatch"],
 }
 
+fc_flags_append = {
+    # "flang-21" : [ "-Xclang -fcf-protection" ],
+}
 
 fc_flags_strip = {
     "flang-7": ["-g"],
@@ -135,24 +138,28 @@ fc_flags_strip = {
         "-fstack-protector-strong",
         "-fstack-clash-protection",
         "-ffile-prefix-map%",
+        "-fcf-protection",
     ],
     "flang-new-19": [
         "-mbranch-protection=standard",
         "-fstack-protector-strong",
         "-fstack-clash-protection",
         "-ffile-prefix-map%",
+        "-fcf-protection",
     ],
     "flang-new-20": [
         "-mbranch-protection=standard",
         "-fstack-protector-strong",
         "-fstack-clash-protection",
         "-ffile-prefix-map%",
+        "-fcf-protection",
     ],
     "flang-21": [
         "-mbranch-protection=standard",
         "-fstack-protector-strong",
         "-fstack-clash-protection",
         "-ffile-prefix-map%",
+        "-fcf-protection",
     ],
 }
 
@@ -175,7 +182,7 @@ ld_flags_strip = {
 }
 
 
-def get_fc_flavor_arch(fc: str) -> str:
+def get_fc_flavor_arch(fc=None) -> str:
     """Given a compiler name, work out flavor and host arch
     Works with cross-compile, validates fc or fails with UsageError
     """
@@ -341,7 +348,7 @@ def get_fc_default(fc=None) -> str:
     return default
 
 
-def get_fc_optional(fc=None) -> str:
+def get_fc_optional(fc=None) -> list[str]:
     """Return the list of other compilers present on the system
     Remove the default from the list if given"""
     d = get_fc_default(fc)
@@ -349,7 +356,7 @@ def get_fc_optional(fc=None) -> str:
         flavors = {f: "1" for f in os.environ["FC_OPTIONAL"].split(" ")}
         if d in flavors:
             del flavors[d]
-        return " ".join(flavors)
+        return flavors
     else:
         compilers_present = {}
         for flavor in compilers:
@@ -357,7 +364,7 @@ def get_fc_optional(fc=None) -> str:
                 if os.path.exists(f"/usr/bin/{exes}"):
                     if flavor != d and flavor not in compilers_present:
                         compilers_present[flavor] = flavor
-        return " ".join(compilers_present)
+        return compilers_present
 
 
 def get_pkg_config_path(flavor: str, arch: str = None) -> str:
@@ -383,14 +390,18 @@ def get_env(flavor: str) -> str:
     fc, arch = get_fc_flavor_arch(flavor)
     f77 = get_f77()
     fc_default = get_fc_default(fc)
-    fc_optional = get_fc_optional(fc)
-
+    fc_optional = " ".join(get_fc_optional(fc))
+    fc_flags = get_fc_flags(fc)
+    fc_ldflags = get_ld_flags(fc, arch)
     return f"""FC={fc}
 F77={f77}
 FC_DEFAULT={fc_default}
 FC_OPTIONAL={fc_optional}
-PKG_CONFIG_PATH={get_pkg_config_path(fc_default)}
-CMAKE_MODULE_PATH={get_cmake_path(fc_default)}
+PKG_CONFIG_PATH={get_pkg_config_path(fc)}
+CMAKE_MODULE_PATH={get_cmake_path(fc)}
+FPM_FC={fc}
+FPM_FFLAGS={fc_flags}
+FPM_LDFLAGS={fc_ldflags}
 """
 
 
