@@ -77,7 +77,8 @@ class ModFileHelper(dh.DhFortranHelper):
         self.modversions = {}
 
     def can_work_automatically(self, *cmdline_files) -> bool:
-        """Should we automatically automagically detect mod files, or work on specified packages?
+        """Should we automatically automagically detect mod files, 
+        or work on specified packages?
 
         Run if we haven't run already, haven't been passed cmdline files,
         """
@@ -88,14 +89,14 @@ class ModFileHelper(dh.DhFortranHelper):
                 return False
         if len(self.config_file_pkgs) != 0:
             cli.verbose_print(
-                "dh_fortran won't run automatically: user has specified fortran-mod files"
+                "dh_fortran won't run automatically: has specified fortran-mod files"
             )
             return False
         if len(self.libdevel_pkgs) != 1:
             return False
         pkg = self.libdevel_pkgs[0]
         cli.verbose_print(
-            f"No fortran-mod files found, 1 libdevel package {pkg}: may install mod files automatically"
+            f"No fortran-mod files found,1 devel package {pkg}: may install mod files automatically"
         )
         return True
 
@@ -134,7 +135,7 @@ class ModFileHelper(dh.DhFortranHelper):
         """Called by DebHelper
         Module file gets copied; metadata gets stored"""
         cli.debug_print(
-            f"process_file [module]  name {oldfile} target_pkg {target_pkg} dest {target_dest}"
+            f"process_file [module]  {oldfile=} {target_pkg=} {target_dest=}"
         )
         try:
             compiler, version = which_compiler_flavor_and_mod_version(oldfile)
@@ -148,7 +149,7 @@ class ModFileHelper(dh.DhFortranHelper):
         self.install_dir(f"{target_pkg}/{dest}")
         self.doit(["cp", oldfile, f"{target_pkg}/{dest}"])
         if oldfile.startswith(self.options.tmpdir):
-             self.doit(["rm",oldfile])
+            self.doit(["rm", oldfile])
 
 
 @click.command(
@@ -160,18 +161,20 @@ class ModFileHelper(dh.DhFortranHelper):
 @cli.debhelper_common_args
 def dh_fortran_mod(files, *args, **kwargs):
     """
-        B<dh_fortran_mod> is a debhelper program that finds Fortran module and submodule files and
-    adds dependencies to B<gfortran-$version> as required to the package using
-    via the variable B<${fortran:Depends}>.
+    B<dh_fortran_mod> is a debhelper program that finds Fortran module 
+    and submodule files and adds dependencies to B<gfortran-$version> 
+    as required to the package using via the variable B<${fortran:Depends}>.
 
-    B<dh_fortran_mod> is expected to be automatically added using the debhelper "addon" B<fortran_mod>
-    ie. either automatically, by build-depending on 'dh-sequence-fortran-mod', or explicitly:
+    B<dh_fortran_mod> is expected to be automatically added using 
+    the debhelper "addon" B<fortran_mod> ie. either automatically, 
+    by build-depending on 'dh-sequence-fortran-mod', or explicitly:
 
         dh $@ --with fortran
 
 
-    B<dh_fortran_mod>Searches the debian/ directory for files B<debian/pkg.fortran-mod>$ which list
-    module files to include, with the same syntax as debhelper install files.
+    B<dh_fortran_mod>Searches the debian/ directory for files 
+    B<debian/pkg.fortran-mod>$ which list module files to include, 
+    with the same syntax as debhelper install files.
 
     =head1 OPTIONS
 
@@ -191,28 +194,34 @@ def dh_fortran_mod(files, *args, **kwargs):
 
     =over 4
 
-    B<dh_fortran_mod> will be expanded to find mod files automatically from the I<debian/tmp> directory.
+    B<dh_fortran_mod> will be expanded to find mod files automatically from the 
+    I<debian/tmp> directory.
     It will enable the installation of mod files in parallel for multiple compilers.
     It will install .smod files for Fortran 2018.
 
-    The fortran-mod file syntax follows dh_install: pairs of sources and optional target directories.
-    The default directory will be $fmoddir ( /usr/lib/$multiarch/fortran/$compiler_mod_directory/)
-    If the target directory is absolute (starts with a  '/'), this directory is used in the target package.
-    If the target  does not absolute, it will be treated as a subdirectory of $fmoddir.
+    The fortran-mod file syntax follows dh_install: pairs of sources and optional
+    target directories.  The default directory will be $fmoddir 
+    ( /usr/lib/$multiarch/fortran/$compiler_mod_directory/)
+    If the target directory is absolute (starts with a  '/'), this directory is used
+    in the target package.  If the target  does not absolute, it will be treated 
+    as a subdirectory of $fmoddir.
 
     Currently four flavours of Fortran compiler are supported: gfortran-*  ('gfortran'),
-    flang-new-* ('flang') , flang-to-external-fc-* ('flangext') and lfortran ('lfortran').
+    flang-new-* ('flang') , flang-to-external-fc-* ('flangext') and 
+    lfortran ('lfortran').
 
-    $compiler_mod_directory is based on the compiler module version: currently gfortran-mod-15 for
-    gfortran-14 (and older), flang-mod-15 for flang-new-15+ and lfortran-mod-0 for lfortran.
+    $compiler_mod_directory is based on the compiler module version: 
+    currently gfortran-mod-15 for gfortran-14 (and older), flang-mod-15 
+    for flang-new-15+ and lfortran-mod-0 for lfortran.
 
-    For flang-to-external-fc-* the version is flangext-mod-15 (assuming gfortran-14 as the external compiler);
-    in principle flang-to-external-fc ('flangext' flavour) and gfortran are intercompatible but
-    intermixing is avoided.
+    For flang-to-external-fc-* the version is flangext-mod-15 (assuming 
+    gfortran-14 as the external compiler); in principle flang-to-external-fc 
+    ('flangext' flavour) and gfortran are intercompatible but intermixing is avoided.
 
     These will be updated for incompatible compiler versions.
 
-    Support for Makefiles and debian/rules is given in /usr/share/debhelper/dh-fortran/fortran-support.mk
+    Support for Makefiles and debian/rules is given in 
+     /usr/share/debhelper/dh-fortran/fortran-support.mk
 
     This enables, for example:
 
