@@ -6,11 +6,32 @@ Copyright (C) 2025 Alastair McKinstry <mckinstry@debian.org>
 Released under the GPL-3 GNU Public License.
 """
 
-from dhfortran.compilers import get_fc_optional, get_fc_default
-from subprocess import check_output
-import dhfortran.cli as cli
+import os
+import subprocess
+import sys
 from os.path import exists
 from functools import wraps
+import dhfortran.cli as cli
+import dhfortran.compilers as cmplrs
+
+
+def _set_env(flavor):
+    """Set Fortran env"""
+    env = (
+        subprocess.check_output(["dh_fortran", "get_env", "--fc", flavor])
+        .strip()
+        .decode("utf-8")
+    )
+    for line in env.split():
+        key, val = line[: line.find("=")], line[line.find("=") + 1 :]
+        os.environ[key] = val
+
+
+def _doit(args):
+    if "DH_VERBOSE" in os.environ:
+        args += ["--verbose"]
+    cli.verbose_print(args)
+    subprocess.run(args, stdout=sys.stdout, stderr=sys.stderr)
 
 
 def foreach_compiler(fail_on_error_on_default=True):
@@ -19,17 +40,20 @@ def foreach_compiler(fail_on_error_on_default=True):
         @wraps(f)
         def inner(*args, **kwargs):
             try:
+                fc_def = cmplrs.get_fc_default()
+                _set_env(fc_def)
                 cli.verbose_print(
-                    f"Calling {f.__name__} with {get_fc_default()}"
+                    f"Calling dh_fortran {f.__name__} with {fc_def} {args} {kwargs}"
                 )  # Pre-function execution
-                f(flavor=get_fc_default(), *args, **kwargs)
+                f(flavor=fc_def, *args, **kwargs)
             except Exception:
                 if fail_on_error_on_default:
                     raise
-            for flavor in get_fc_optional():
+            for flavor in cmplrs.get_fc_optional():
                 try:
+                    _set_env(flavor)
                     cli.verbose_print(
-                        f"Calling {f.__name__} with {flavor}"
+                        f"Calling dh_fortran {f.__name__} with {flavor} {args} {kwargs}"
                     )  # Pre-function execution
                     f(flavor)
                 except Exception as ex:
@@ -40,44 +64,50 @@ def foreach_compiler(fail_on_error_on_default=True):
     return outer
 
 
-# @foreach_compiler(fail_on_error_on_default=False)
+@foreach_compiler(fail_on_error_on_default=False)
 def clean(flavor: str = None):
     """Do Fortran-specific operations on d/rules clean target"""
-    cli.verbose_print("dh_fortran clean called")
+    cli.verbose_print(f"dh_fortran clean called - {flavor}")
     if exists("fpm.toml"):
-        check_output(["fpm", "clean", "--all"])
+        _doit(["fpm", "clean", "--all"])
+        _doit(["rm", "-rf", "debian/tmp-*", "debian/build-*"])
 
 
-# @foreach_compiler
+@foreach_compiler()
 def install(flavor: str = None):
     """Do Fortran-specific operations on d/rules install target"""
     cli.verbose_print("dh_fortran install called")
+    if flavor is None:
+        flavor, _ = cmplrs.get_fc_flavor_arch()
     if exists("fpm.toml"):
         # TODO. paramterise tmpdir debian/tmp ?
-        check_output(["fpm", "install", "--prefix=debian/tmp/usr"])
+        _doit(["fpm", "install", f"--prefix=debian/tmp-{flavor}/usr"])
+        _doit(["dh_fortran_mod", f"--tmpdir=debian/tmp-{flavor}"])
+        _doit(["dh_fortran_lib", f"--tmpdir=debian/tmp-{flavor}"])
+        _doit(["dh_fortran_pkgconf", f"--tmpdir=debian/tmp-{flavor}"])
+        _doit(["dh_fortran_cmake", f"--tmpdir=debian/tmp-{flavor}"])
 
 
-# @foreach_compiler
 def configure(flavor: str = None):
     """Do Fortran-specific operations on d/rules configure target"""
     cli.verbose_print("dh_fortran configure called")
 
 
-# @foreach_compiler
+@foreach_compiler()
 def build(flavor: str = None):
     """Do Fortran-specific operations on d/rules build target"""
     cli.verbose_print("dh_fortran build called")
     if exists("fpm.toml"):
-        check_output(["fpm", "build"])
+        _doit(["fpm", "build"])
         # TODO: Call fpm build as relevant
 
 
-# @foreach_compiler
+@foreach_compiler()
 def test(flavor: str = None):
     """Do Fortran-specific operations on d/rules test target"""
     cli.verbose_print("dh_fortran test called")
     if exists("fpm.toml"):
-        check_output(["fpm", "test"])
+        _doit(["fpm", "test"])
 
 
 if __name__ == "__main__":
