@@ -95,10 +95,14 @@ sub new {
 sub set_fortran_env {
     my $this = shift;
     # print "set_fortran_env";
-    # doit('dh_fortran','env');
-    # TODO Defaults
-    $ENV{FC_DEFAULT} = 'gfortran-15';
-    # $ENV{FC_OPTIONAL} = 'gfortran-14 flang-new-21';
+    open(my $fh, "-|", "dh_fortran get_env") or die "Cannot open pipe: $!";
+    while (my $line = <$fh>) {
+       chomp $line;
+       next if $line =~ /^\s*$/ || $line =~ /^\s*#/;
+       my ($key, $value) = split /=/, $line, 2;
+       $ENV{$key} = $value;
+   }
+   close($fh);
 }
 
 
